@@ -18,7 +18,7 @@ enum Command {
     #[clap(setting(AppSettings::DeriveDisplayOrder))]
     Download {
         /// REQUIRED: output directory to create
-        #[clap(short, long, required=true)]
+        #[clap(short, long, required = true)]
         output_dir: String,
 
         /// if to delete previous output directory (default: false)
@@ -26,7 +26,7 @@ enum Command {
         delete_previous_dir: bool,
 
         /// symmetric secrets encryption hex key for aes GCM (lower case 64 chars)
-        #[clap(long, required=false)]
+        #[clap(long, required = false)]
         secrets_encryption_key: Option<String>,
 
         /// disable default excluded types
@@ -34,7 +34,7 @@ enum Command {
         no_default_excluded_types: bool,
 
         /// add additional excluded types
-        #[clap(long, required=false)]
+        #[clap(long, required = false)]
         excluded_types: Vec<String>,
     },
 
@@ -48,27 +48,22 @@ enum Command {
 pub struct AppConfig {
     pub output_dir: String,
     pub delete_previous_dir: bool,
-    pub secrets_encryption_key: Option<String>,
+    pub secrets_encryption_key: Option<Vec<u8>>,
     pub excluded_types: Vec<String>,
 }
 
 impl Default for AppConfig {
     fn default() -> Self {
-        return AppConfig {
+        AppConfig {
             output_dir: "test".to_string(),
             delete_previous_dir: false,
             secrets_encryption_key: None,
             excluded_types: default_resources_excluded(),
-        };
+        }
     }
 }
 
 impl AppConfig {
-
-    pub fn encryption_key_bytes(&self) -> Option<Vec<u8>> {
-        return self.secrets_encryption_key.as_ref().map(|x| hex::decode(x).unwrap());
-    }
-
     pub fn from_cli_args() -> AppConfig {
         let cli_args: CliArgs = CliArgs::parse();
         match cli_args.command {
@@ -80,7 +75,8 @@ impl AppConfig {
                 std::process::exit(0);
             }
             Command::ClusterResourceTypes => {
-                let types = util::k8s::kubectl::api_resource_types();
+                let types = util::k8s::kubectl::api_resource_types()
+                    .expect("Failed to download k8s resource types");
                 println!("Cluster types:");
                 for tpe in types.accessible.all {
                     println!(" - {}", tpe.qualified_name());
@@ -98,45 +94,37 @@ impl AppConfig {
                 if no_default_excluded_types {
                     result.excluded_types.clear();
                 }
-                result.excluded_types.append(&mut excluded_types.to_owned());
-                result.secrets_encryption_key = secrets_encryption_key;
+                result.excluded_types.extend_from_slice(&excluded_types);
+                result.secrets_encryption_key = secrets_encryption_key.map(|x| parse_encryption_key(&x));
                 result.delete_previous_dir = delete_previous_dir;
                 result.output_dir = output_dir;
 
-                for key_str in &result.secrets_encryption_key {
-                    log::info!("verifying encryption key length and format...");
-                    if key_str.len() != 64 {
-                        panic!("key string was of size {}, must be exactly 64 hex characters", key_str.len());
-                    }
-                    hex::decode(key_str).expect("key was not a valid hex string");
-                }
-
-                return result;
+                result
             }
         }
     }
 
     pub fn include_secrets(&self) -> bool {
-        return self.secrets_encryption_key.is_some();
+        self.secrets_encryption_key.is_some()
     }
 
     pub fn is_type_included(&self, tpe: &util::k8s::ApiResourceType) -> bool {
-        return !self.excluded_types.contains(&tpe.name) &&
+        !self.excluded_types.contains(&tpe.name) &&
             !self.excluded_types.contains(&tpe.qualified_name()) &&
-            (!tpe.is_secret() || self.include_secrets());
+            (!tpe.is_secret() || self.include_secrets())
     }
 
     pub fn types_do_download<'a>(&self, all_resource_type_defs: &'a util::k8s::kubectl::ApiResourceTypes) -> Vec<&'a ApiResourceType> {
-        return all_resource_type_defs.accessible.all
+        all_resource_type_defs.accessible.all
             .iter()
             .filter(|x| self.is_type_included(x))
-            .collect::<Vec<&ApiResourceType>>();
+            .collect::<Vec<&ApiResourceType>>()
     }
 }
 
 
 pub fn default_resources_excluded() -> Vec<String> {
-    return vec![
+    vec![
         "limitranges",
         "podtemplates",
         "replicationcontrollers",
@@ -183,6 +171,14 @@ pub fn default_resources_excluded() -> Vec<String> {
         "certificatesigningrequests.certificates.k8s.io",
         "ingresses.extensions",
         "pods.metrics.k8s.io",
-    ].iter().map(|x| x.to_string()).collect();
+    ].iter().map(|x| x.to_string()).collect()
 }
 
+
+fn parse_encryption_key(hex_str: &str) -> Vec<u8> {
+    log::info!("verifying encryption key length and format...");
+    if hex_str.len() != 64 {
+        panic!("key string was of size {}, must be exactly 64 hex characters", hex_str.len());
+    }
+    hex::decode(hex_str).expect("key was not a valid hex string")
+}
